mavix library

Classes

Mavix<S, A>
The base Mavix state manager.
MavixActivitySource<Activity>
A source of one-time activities.
MavixBuilder<M extends MavixStateSource<S>, S>
MavixChange<S>
Describes a Mavix state change.
MavixConfig
Global Mavix configuration.
MavixDisposable
An object that owns resources and can be closed.
MavixListener<M extends MavixActivitySource<A>, A>
Listens to one-time activities.
MavixLogObserver
A default observer that prints debug information to the console.
MavixMultiListener
Combines multiple MavixListener widgets without manual nesting.
MavixMultiProvider
Combines multiple MavixProvider widgets without manual nesting.
MavixMultiRepositoryProvider
Combines multiple MavixRepositoryProvider widgets without manual nesting.
MavixNestableWidget
A widget that can be automatically nested inside another widget.
MavixObserver
A global observer for Mavix instances.
MavixProvider<M extends MavixDisposable>
Provides a Mavix instance to the widget subtree.
MavixRepositoryProvider<R>
Provides a repository to the widget subtree.
MavixSelector<M extends MavixStateSource<S>, S, T>
MavixStateSource<State>
A source of the current state and its future updates.

Typedefs

MavixActivityListener<A> = void Function(BuildContext context, A activity)
MavixBuildWhen<S> = bool Function(S previous, S current)
MavixCreate<M extends MavixDisposable> = M Function(BuildContext context)
MavixListenWhen<A> = bool Function(A activity)
MavixRepositoryCreate<R> = R Function(BuildContext context)
MavixRepositoryDispose<R> = FutureOr<void> Function(R repository)
MavixSelectedBuilder<T> = Widget Function(BuildContext context, T value)
MavixStateSelector<S, T> = T Function(S state)
MavixWidgetBuilder<S> = Widget Function(BuildContext context, S state)